.. py:function:: sf_ellint_Dcomp_e(k, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_ellint_Dcomp_e`
    c code signature: int gsl_sf_ellint_Dcomp_e( double k,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rl__Ord`
    
    :param double k: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_ellint_Dcomp(k, mode [, ret])

    Wrapper for :c:func:`gsl_sf_ellint_Dcomp`
    c code signature: double gsl_sf_ellint_Dcomp( double k,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rd__O`
    
    :param double k: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_ellint_Pcomp_e(k, n, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_ellint_Pcomp_e`
    c code signature: int gsl_sf_ellint_Pcomp_e( double k,  double n,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_m__Rl__Ord`
    
    :param double k: positional argument 0
    :param double n: positional argument 1
    :param gsl_mode_t mode: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_ellint_RJ(x, y, z, p, mode [, ret])

    Wrapper for :c:func:`gsl_sf_ellint_RJ`
    c code signature: double gsl_sf_ellint_RJ( double x,  double y,  double z,  double p,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_d_m__Rd__O`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param double z: positional argument 2
    :param double p: positional argument 3
    :param gsl_mode_t mode: positional argument 4
    :param double ret: positional argument 5
    :rtype:  double 
    :return: result 

.. py:function:: sf_ellint_P(phi, k, n, mode [, ret])

    Wrapper for :c:func:`gsl_sf_ellint_P`
    c code signature: double gsl_sf_ellint_P( double phi,  double k,  double n,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_m__Rd__O`
    
    :param double phi: positional argument 0
    :param double k: positional argument 1
    :param double n: positional argument 2
    :param gsl_mode_t mode: positional argument 3
    :param double ret: positional argument 4
    :rtype:  double 
    :return: result 

.. py:function:: sf_ellint_Ecomp_e(k, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_ellint_Ecomp_e`
    c code signature: int gsl_sf_ellint_Ecomp_e( double k,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rl__Ord`
    
    :param double k: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_ellint_RF_e(x, y, z, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_ellint_RF_e`
    c code signature: int gsl_sf_ellint_RF_e( double x,  double y,  double z,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_m__Rl__Ord`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param double z: positional argument 2
    :param gsl_mode_t mode: positional argument 3
    :param int ret: positional argument 4
    :param double result.val: positional argument 5
    :param double result.err: positional argument 6
    :rtype:  tuple(:param int ret: positional argument 4, :param double result.val: positional argument 5, :param double result.err: positional argument 6) 
    :return: result 

.. py:function:: sf_ellint_E_e(phi, k, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_ellint_E_e`
    c code signature: int gsl_sf_ellint_E_e( double phi,  double k,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_m__Rl__Ord`
    
    :param double phi: positional argument 0
    :param double k: positional argument 1
    :param gsl_mode_t mode: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_ellint_RC_e(x, y, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_ellint_RC_e`
    c code signature: int gsl_sf_ellint_RC_e( double x,  double y,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_m__Rl__Ord`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param gsl_mode_t mode: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_ellint_Kcomp_e(k, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_ellint_Kcomp_e`
    c code signature: int gsl_sf_ellint_Kcomp_e( double k,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rl__Ord`
    
    :param double k: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_ellint_Kcomp(k, mode [, ret])

    Wrapper for :c:func:`gsl_sf_ellint_Kcomp`
    c code signature: double gsl_sf_ellint_Kcomp( double k,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rd__O`
    
    :param double k: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_ellint_RD_e(x, y, z, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_ellint_RD_e`
    c code signature: int gsl_sf_ellint_RD_e( double x,  double y,  double z,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_m__Rl__Ord`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param double z: positional argument 2
    :param gsl_mode_t mode: positional argument 3
    :param int ret: positional argument 4
    :param double result.val: positional argument 5
    :param double result.err: positional argument 6
    :rtype:  tuple(:param int ret: positional argument 4, :param double result.val: positional argument 5, :param double result.err: positional argument 6) 
    :return: result 

.. py:function:: sf_ellint_F(phi, k, mode [, ret])

    Wrapper for :c:func:`gsl_sf_ellint_F`
    c code signature: double gsl_sf_ellint_F( double phi,  double k,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_m__Rd__O`
    
    :param double phi: positional argument 0
    :param double k: positional argument 1
    :param gsl_mode_t mode: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_ellint_D_e(phi, k, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_ellint_D_e`
    c code signature: int gsl_sf_ellint_D_e( double phi,  double k,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_m__Rl__Ord`
    
    :param double phi: positional argument 0
    :param double k: positional argument 1
    :param gsl_mode_t mode: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_ellint_D(phi, k, mode [, ret])

    Wrapper for :c:func:`gsl_sf_ellint_D`
    c code signature: double gsl_sf_ellint_D( double phi,  double k,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_m__Rd__O`
    
    :param double phi: positional argument 0
    :param double k: positional argument 1
    :param gsl_mode_t mode: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_ellint_E(phi, k, mode [, ret])

    Wrapper for :c:func:`gsl_sf_ellint_E`
    c code signature: double gsl_sf_ellint_E( double phi,  double k,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_m__Rd__O`
    
    :param double phi: positional argument 0
    :param double k: positional argument 1
    :param gsl_mode_t mode: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_ellint_RJ_e(x, y, z, p, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_ellint_RJ_e`
    c code signature: int gsl_sf_ellint_RJ_e( double x,  double y,  double z,  double p,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_d_m__Rl__Ord`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param double z: positional argument 2
    :param double p: positional argument 3
    :param gsl_mode_t mode: positional argument 4
    :param int ret: positional argument 5
    :param double result.val: positional argument 6
    :param double result.err: positional argument 7
    :rtype:  tuple(:param int ret: positional argument 5, :param double result.val: positional argument 6, :param double result.err: positional argument 7) 
    :return: result 

.. py:function:: sf_ellint_RF(x, y, z, mode [, ret])

    Wrapper for :c:func:`gsl_sf_ellint_RF`
    c code signature: double gsl_sf_ellint_RF( double x,  double y,  double z,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_m__Rd__O`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param double z: positional argument 2
    :param gsl_mode_t mode: positional argument 3
    :param double ret: positional argument 4
    :rtype:  double 
    :return: result 

.. py:function:: sf_ellint_Pcomp(k, n, mode [, ret])

    Wrapper for :c:func:`gsl_sf_ellint_Pcomp`
    c code signature: double gsl_sf_ellint_Pcomp( double k,  double n,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_m__Rd__O`
    
    :param double k: positional argument 0
    :param double n: positional argument 1
    :param gsl_mode_t mode: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: sf_ellint_Ecomp(k, mode [, ret])

    Wrapper for :c:func:`gsl_sf_ellint_Ecomp`
    c code signature: double gsl_sf_ellint_Ecomp( double k,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_m__Rd__O`
    
    :param double k: positional argument 0
    :param gsl_mode_t mode: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_ellint_RD(x, y, z, mode [, ret])

    Wrapper for :c:func:`gsl_sf_ellint_RD`
    c code signature: double gsl_sf_ellint_RD( double x,  double y,  double z,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_m__Rd__O`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param double z: positional argument 2
    :param gsl_mode_t mode: positional argument 3
    :param double ret: positional argument 4
    :rtype:  double 
    :return: result 

.. py:function:: sf_ellint_F_e(phi, k, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_ellint_F_e`
    c code signature: int gsl_sf_ellint_F_e( double phi,  double k,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_m__Rl__Ord`
    
    :param double phi: positional argument 0
    :param double k: positional argument 1
    :param gsl_mode_t mode: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_ellint_P_e(phi, k, n, mode [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_ellint_P_e`
    c code signature: int gsl_sf_ellint_P_e( double phi,  double k,  double n,  gsl_mode_t mode, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_m__Rl__Ord`
    
    :param double phi: positional argument 0
    :param double k: positional argument 1
    :param double n: positional argument 2
    :param gsl_mode_t mode: positional argument 3
    :param int ret: positional argument 4
    :param double result.val: positional argument 5
    :param double result.err: positional argument 6
    :rtype:  tuple(:param int ret: positional argument 4, :param double result.val: positional argument 5, :param double result.err: positional argument 6) 
    :return: result 

.. py:function:: sf_ellint_RC(x, y, mode [, ret])

    Wrapper for :c:func:`gsl_sf_ellint_RC`
    c code signature: double gsl_sf_ellint_RC( double x,  double y,  gsl_mode_t mode)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_m__Rd__O`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param gsl_mode_t mode: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

